@@ -3,13 +3,13 @@ import sys
 import os
 import importlib
 import argparse
-from typing import Dict
+from typing import Dict, Union
 
 from checking.runner import start
-from checking.helpers.others import is_file_exists
+from checking.helpers.others import is_file_exists, str_date_time
 
 HOME_FOLDER = sys.path[0]
-look_for = ('import checking', 'from checking')
+LOOK_FOR = ('import checking', 'from checking')
 
 
 def read_parameters_from_file(file_name) -> Dict:
@@ -18,7 +18,7 @@ def read_parameters_from_file(file_name) -> Dict:
     """
     with open(file_name, encoding='utf-8') as file:
         result = ''.join([line.rstrip() for line in file.readlines()])
-    params = {'verbose': 0, 'groups': [], 'params': {}, 'listener': '', 'modules': [], 'threads': 1}
+    params = _get_default_params()
     params.update(json.loads(result))
     return params
 
@@ -55,9 +55,14 @@ def check_parameters(parameters: Dict):
             raise ValueError('Dry_run parameter must be bool (True or False)!')
 
 
-def start_with_parameters(parameters: Dict):
+def _get_default_params():
     params = {'name': 'Default Test Suite', 'verbose': 0, 'groups': [], 'params': {}, 'listener': '', 'modules': [],
               'threads': 1, 'dry_run': False}
+    return params
+
+
+def start_with_parameters(parameters: Dict):
+    params = _get_default_params()
     params.update(parameters)
     check_parameters(params)
     verbose = params.get('verbose')
@@ -98,9 +103,9 @@ def _is_import_in_file(file_name: str) -> bool:
     with open(file_name, encoding='utf-8') as file:
         for line in file.readlines():
             line = line.rstrip().replace('  ', ' ')
-            if any([element in line for element in look_for]):
+            if any([element in line for element in LOOK_FOR]):
                 return True
-        return False
+    return False
 
 
 def _walk_throw_and_import():
@@ -114,37 +119,76 @@ def _walk_throw_and_import():
             continue
         for file in (f for f in files if _is_import_in_file(f'{root}{os.sep}{f}')):
             package_ = root.replace(HOME_FOLDER, '').replace(os.sep, '')
-            file_name = file.replace('.py', '')
-            name = package_ + '.' + file_name if package_ else file_name
+            file_name_ = file.replace('.py', '')
+            name = package_ + '.' + file_name_ if package_ else file_name_
             importlib.import_module(name, package=HOME_FOLDER)
 
 
-if __name__ == '__main__':
+def _generate_options():
+    """
+    Generates default options<date+time>.json file at current folder
+    :return: None
+    """
+    with open(f'options_{str_date_time()}.json', 'wt') as file:
+        json.dump(_get_default_params(), file)
+
+
+def _get_file_name(arg: Union[str, None]) -> str:
+    name = 'options.json'
+    if arg:
+        name = arg
+        if not name.endswith('.json'):
+            raise ValueError('Only <name>.json files allowed! And it must contains valid json, '
+                             'you can generate it with -g option')
+    return name
+
+
+def _get_arg_dict(arg: Union[str, None]) -> Dict:
+    dic_ = {}
+    if arg:
+        if '=' in args.arg:
+            dic_[arg.split('=')[0]] = arg.split('=')[1]
+        else:
+            dic_[arg] = None
+    return dic_
+
+
+def parse_arguments() -> argparse.Namespace:
     parser = argparse.ArgumentParser()
     parser.add_argument('-o', '--options_file', help="File with the options to run")
-    parser.add_argument('-a', '--arg', help="Any Argument for test-suite")
-    parser.add_argument('-d', '--dry_run', help="Boolean arg for dry_run (run without actual functions executed!",
+    parser.add_argument('-a', '--arg', help="Any argument for test-suite")
+    parser.add_argument('-d', '--dry_run', help="Boolean arg for dry_run (run without actual functions executed)!",
                         type=bool)
-    args = parser.parse_args()
-    file_name = 'options.json'
-    if args.options_file:
-        file_name = args.options_file
-    p_ = {}
-    if args.arg:
-        if '=' in args.arg:
-            p_[args.arg.split('=')[0]] = args.arg.split('=')[1]
-        else:
-            p_[args.arg] = None
-    dry_run = args.dry_run if args.dry_run else False
-    # если есть файл настроек то берем все оттуда
-    if is_file_exists(file_name):
-        print(f"{file_name} found! Work with it...")
-        params_ = read_parameters_from_file(file_name)
+    parser.add_argument('-g', '--generate_options',
+                        help="Not doing any work, just generates options.json in current folder!", action='store_const',
+                        const=True)
+    return parser.parse_args()
+
+
+def _main_run(file_name_: str, p_: Dict, dry_run: bool):
+    # if options file exists get all from there
+    if is_file_exists(file_name_):
+        print(f"{file_name_} found! Work with it...")
+        params_ = read_parameters_from_file(file_name_)
         if p_:
             params_.get("params").update(p_)
         start_with_parameters(params_)
-    # иначе проходим по всем модулям в поисках тестов
+    # or walk recursive and find all modules with tests
     else:
-        print(f"No options found! Starts to look for tests in all sub-folders")
-        _walk_throw_and_import()
-        start(verbose=3, threads=1, params=p_, dry_run=dry_run)
+        if file_name_ == 'options.json':
+            print(f"No options found! Starts to look for tests in all sub-folders")
+            _walk_throw_and_import()
+            start(verbose=3, threads=1, params=p_, dry_run=dry_run)
+        else:
+            raise ValueError(f"{file_name_} not found! Stopped")
+
+
+if __name__ == '__main__':
+    args = parse_arguments()
+    if args.generate_options:
+        _generate_options()
+    else:
+        file_name = _get_file_name(args.options_file)
+        p_ = _get_arg_dict(args.arg)
+        dry_run = args.dry_run if args.dry_run else False
+        _main_run(file_name, p_, dry_run)
